package models

import (
	"time"

	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"
	"gitlab.bit9.local/psc/ems/hinting/internal/metrics"
)

var _ = Describe("Postgres DeviceGroup Model tests", func() {
	It("results in nil dimensions with 'empty' device group", func() {
		d := &DeviceGroup{}

		m := d.GetMetricDimensions()

		Expect(m).To(BeNil())
	})

	It("results in nil even if dimensions if OrgKey, env, and Id are set", func() {
		d := &DeviceGroup{
			OrgKey: "ABC",
			env:    "local",
			Id:     int64(1),
		}

		m := d.GetMetricDimensions()

		Expect(m).To(BeNil())
	})

	It("properly sets dimensions with a single hint", func() {
		d := &DeviceGroup{
			OrgKey:              "ABC",
			env:                 "local",
			Id:                  int64(1),
			LiveQueryChangeTime: func(t time.Time) *time.Time { return &t }(time.Now()),
		}

		m := d.GetMetricDimensions()

		Expect(m).ToNot(BeNil())
		Expect(*m).To(Equal(metrics.Dimensions{
			metrics.DimensionOrgKey:  "ABC",
			metrics.DimensionEnvName: "local",
			"device_group_id":        "1",
			"dg_hints":               "dg_LiveQueryChangeTime",
		}))
	})

	It("properly sets dimensions with multiple hints", func() {
		d := &DeviceGroup{
			OrgKey:               "ABC",
			env:                  "local",
			Id:                   int64(1),
			LiveQueryChangeTime:  func(t time.Time) *time.Time { return &t }(time.Now()),
			LastPolicyChangeTime: func(t time.Time) *time.Time { return &t }(time.Now()),
		}

		m := d.GetMetricDimensions()

		Expect(m).ToNot(BeNil())
		Expect(*m).To(Equal(metrics.Dimensions{
			metrics.DimensionOrgKey:  "ABC",
			metrics.DimensionEnvName: "local",
			"device_group_id":        "1",
			"dg_hints":               "dg_LiveQueryChangeTime,dg_LastPolicyChangeTime",
		}))
	})
})
