package models

import (
	"time"

	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"
	"gitlab.bit9.local/psc/ems/hinting/internal/metrics"
)

var _ = Describe("Postgres Device Model tests", func() {
	It("results in nil dimensions with 'empty' device", func() {
		d := &Device{}

		m := d.GetMetricDimensions()

		Expect(m).To(BeNil())
	})

	It("results in nil dimensions if OrgKey and env are set", func() {
		d := &Device{
			OrgKey: "ABC",
			env:    "local",
		}

		m := d.GetMetricDimensions()

		Expect(m).To(BeNil())
	})

	It("properly sets dimensions with a single hint", func() {
		d := &Device{
			OrgKey:          "ABC",
			env:             "local",
			GroupChangeTime: func(t time.Time) *time.Time { return &t }(time.Now()),
		}

		m := d.GetMetricDimensions()

		Expect(m).ToNot(BeNil())
		Expect(*m).To(Equal(metrics.Dimensions{
			metrics.DimensionOrgKey:  "ABC",
			metrics.DimensionEnvName: "local",
			"dev_hints":              "dev_GroupChangeTime",
		}))
	})

	It("properly sets dimensions with multiple hints", func() {
		d := &Device{
			OrgKey:                      "ABC",
			env:                         "local",
			GroupChangeTime:             func(t time.Time) *time.Time { return &t }(time.Now()),
			LiveQueryChangeTime:         func(t time.Time) *time.Time { return &t }(time.Now()),
			HashUploadRequestTime:       func(t time.Time) *time.Time { return &t }(time.Now()),
			HashDeleteRequestTime:       func(t time.Time) *time.Time { return &t }(time.Now()),
			LogsRequestTime:             func(t time.Time) *time.Time { return &t }(time.Now()),
			PerfmonTriggerTime:          func(t time.Time) *time.Time { return &t }(time.Now()),
			RepRequestTime:              func(t time.Time) *time.Time { return &t }(time.Now()),
			ReRegisterTime:              func(t time.Time) *time.Time { return &t }(time.Now()),
			SensorActionTime:            func(t time.Time) *time.Time { return &t }(time.Now()),
			SensorCertificateUpdateTime: func(t time.Time) *time.Time { return &t }(time.Now()),
			SensorConfigUpdateTime:      func(t time.Time) *time.Time { return &t }(time.Now()),
			SensorKitUpdateTime:         func(t time.Time) *time.Time { return &t }(time.Now()),
		}

		m := d.GetMetricDimensions()

		Expect(m).ToNot(BeNil())
		Expect(*m).To(Equal(metrics.Dimensions{
			metrics.DimensionOrgKey:  "ABC",
			metrics.DimensionEnvName: "local",
			"dev_hints":              "dev_GroupChangeTime,dev_SensorConfigUpdateTime,dev_SensorCertificateUpdateTime,dev_HashDeleteRequestTime,dev_HashUploadRequestTime,dev_LogsRequestTime,dev_SensorKitUpdateTime,dev_PerfmonTriggerTime,dev_SensorActionTime,dev_ReRegisterTime,dev_LiveQueryChangeTime,dev_RepRequestTime",
		}))
	})
})
