// Copyright (c) 2022-2023 VMware Carbon Black, all rights reserved

// Package devicegroupchangetype -- enumeration copied from the monolith concerned with device group change types
package devicegroupchangetype

//go:generate stringer -type=DeviceGroupChangeType

// DeviceGroupChangeType -- Type alias of allowed device group change types
type DeviceGroupChangeType int

// NOTE: Changes here should also be reflected in `test/functional/suites/lib/models/enumerations.py`

// NOTE: Keep in sync with:
//   - https://gitlab.bit9.local/cb-defense/cbd/-/blob/main/backend/domainModel/src/main/java/com/scargo/domainmodel/entity/support/ChangeTimestampType.java
//
//goland:noinspection GoSnakeCaseUsage
const (
	DG_POLICY_CHANGE             DeviceGroupChangeType = 201 // Device Group Policy settings
	DG_DISABLE_SENSOR_AUTOUPDATE DeviceGroupChangeType = 202 // Disable device group auto-update
	DG_LIVE_QUERY_CHANGE         DeviceGroupChangeType = 203 // Device group level live query
)

//goland:noinspection GoSnakeCaseUsage,GoUnusedGlobalVariable
var (
	// TranslateDeviceGroupChangeTypeString -- Translation from string -> DeviceGroupChangeType
	//  - Limited to those device group change types used by hinting
	TranslateDeviceGroupChangeTypeString = map[string]DeviceGroupChangeType{ //nolint:gochecknoglobals // we don't care
		DG_POLICY_CHANGE.String():     DG_POLICY_CHANGE,
		DG_LIVE_QUERY_CHANGE.String(): DG_LIVE_QUERY_CHANGE,
	}
)
