package metrics

import (
	"golang.org/x/exp/maps"
)

const (
	DimensionOrgKey  = "org_key"
	DimensionEnvName = "env_name"
)

type Dimensions map[string]string

type Metric struct {
	Name       string
	Dimensions Dimensions
}

type MetricsClientWrapper struct {
	metricsClient Service
}

func NewMetricsClientWrapper(metricsClient Service) *MetricsClientWrapper {
	return &MetricsClientWrapper{
		metricsClient: metricsClient,
	}
}

func (m *MetricsClientWrapper) Count(metricName string, dimensions []*Dimensions) {
	if m.metricsClient == nil {
		return
	}

	mergedDimensions := Dimensions{}

	for _, dimension := range dimensions {
		if dimension != nil {
			maps.Copy(mergedDimensions, *dimension)
		}
	}

	if len(mergedDimensions) == 0 {
		mergedDimensions = nil
	}

	m.metricsClient.Count(metricName, mergedDimensions, 1)
}
