package metrics

import (
	"time"

	. "github.com/onsi/ginkgo/v2"
	"github.com/opentracing/opentracing-go"
	"gitlab.bit9.local/psc/ems/hinting/pkg/enums/devicetype"
)

type metricsClientMock struct{}

func (m metricsClientMock) TrackMethodTime(name string, start time.Time, dims map[string]string) {}
func (m metricsClientMock) Count(name string, dimensions map[string]string, value int64)         {}
func (m metricsClientMock) Gauge(name string, dimensions map[string]string, value int64)         {}
func (m metricsClientMock) Histogram(name string, dimensions map[string]string, value int64)     {}
func (m metricsClientMock) RegisterMetric(name string, metric interface{}, tags map[string]string) error {
	return nil
}
func (m metricsClientMock) Tracer() opentracing.Tracer { return nil }
func (m metricsClientMock) CloseConnection()           {}

var _ = Describe("Metrics Client Wrapper tests", func() {
	metricsWrapper := NewMetricsClientWrapper(metricsClientMock{})

	It("should do nothing when passing in a bunch of nil dimensions", func() {
		metricsWrapper.Count("test", []*Dimensions{nil, nil, nil, nil})
	})

	It("should behave correctly with some nil and some non nil", func() {
		envDimensions := Dimensions{
			DimensionEnvName:     "local",
			"env_canary_payload": string(devicetype.WINDOWS) + "," + string(devicetype.MAC),
		}

		orgDimensions := Dimensions{
			DimensionOrgKey:      "ABC",
			DimensionEnvName:     "local",
			"is_killswitch_on":   "true",
			"org_canary_payload": string(devicetype.WINDOWS) + "," + string(devicetype.MAC),
		}

		metricsWrapper.Count("test", []*Dimensions{
			&envDimensions, &orgDimensions, nil, nil,
		})
	})
})
