package redisclient

import (
	"context"
	"testing"
	"time"

	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"
)

type mockRedisClient struct {
	RedisClient
	getContext context.Context
	setContext context.Context
	delContext context.Context
}

func (mrc *mockRedisClient) Get(ctx context.Context, cacheKey string) ([]byte, error) {
	mrc.getContext = ctx
	return nil, nil
}

func (mrc *mockRedisClient) Set(ctx context.Context, cacheKey string, data []byte) error {
	mrc.setContext = ctx
	return nil
}

func (mrc *mockRedisClient) Del(ctx context.Context, cacheKey string) error {
	mrc.delContext = ctx
	return nil
}

var _ = Describe("Redis Client With Timeout", func() {
	mockclient := mockRedisClient{}
	redisClientWithTimeout := redisClientWithTimeout{timeout: time.Second, RedisClient: &mockclient}
	It("Applies timeouts to each operation", func() {
		testContext := context.TODO()
		_ = redisClientWithTimeout.Set(testContext, "blah", nil)
		_, found := mockclient.setContext.Deadline()
		Expect(found).To(BeTrue())
		_, _ = redisClientWithTimeout.Get(testContext, "blah")
		_, found = mockclient.getContext.Deadline()
		Expect(found).To(BeTrue())
		_ = redisClientWithTimeout.Del(testContext, "blah")
		_, found = mockclient.delContext.Deadline()
		Expect(found).To(BeTrue())
	})
},
)

func TestRedisClientWithTimeout(t *testing.T) {
	RegisterFailHandler(Fail)
	RunSpecs(t, "redisClient tests")
}
